import type { ExtractPropTypes } from 'vue-demi';
import type { CommonMethod } from '../constant';
import type { wrapperProps } from './props';
/** 外部需传递的 props */
export type WrapperProps = ExtractPropTypes<typeof wrapperProps>;
/** 外部传递的方法 */
export interface WrapperOption {
    /** 触发搜索事件 */
    search?: (params: Record<string, any>) => void;
    /** 触发重置事件 */
    reset?: (params: Record<string, any>) => void;
    /**
     * 字段值发生改变时触发
     * @param {object} option 提供的
     * @param {string} option.field 实际改变的键
     * @param {*} option.value
     * @param {object} option.query
     * @param {string} option.nativeField 原始健(不受 as, fields 等属性影响)
     */
    fieldChange?: (option: {
        field: string;
        value: any;
        query: Record<string, any>;
        nativeField: string;
    }) => void;
}
/** 封装 wrapper 组件必备的信息 */
export declare function useWrapper(props: WrapperProps, option?: WrapperOption): {
    child: CommonMethod[];
    wrapperInstance: {
        realtime: import("vue-demi").Ref<boolean>;
        queryChangedInWrapper: import("vue-demi").Ref<boolean>;
        register(compOption: CommonMethod): () => void;
        updateQueryValue(field: string, value: any, nativeField: string): void;
        insetSearch(): void;
        search: () => Promise<void>;
        removeUnreferencedField(field: string): void;
        options: Record<string, any>;
    };
    query: import("vue-demi").Ref<Record<string, string>>;
    getQuery: () => {
        [x: string]: string;
    };
    search: () => Promise<void>;
    reset: () => void;
    resetField: (allowEmptyValue?: boolean) => void;
    validate: () => Promise<string>;
};
