import type { VNode } from 'vue-demi';
/**
 * 空值转为提供的默认值
 * @param {*} val 值为空时转为默认值
 * @param {*} defaultVal
 */
export declare function emptyToValue<T>(val: any, defaultVal: T): any;
/** 判断两个值是否相等, 排除掉空值 */
export declare function isEqualExcludeEmptyValue(x: any, y: any): boolean;
/** 判断是否是空值(null, undefined, '') */
export declare function isEmptyValue(val: any): boolean;
/** 判断两个值是否一致 */
export declare function isEqual(x: any, y: any): boolean;
/** 判断是否是原始类型(number , string , boolean , symbol, bigint, undefined, null) */
export declare function isPrimitive(value: any): boolean;
/** 拷贝 */
export declare function clone<T>(obj: T, deep?: boolean): T;
/**
 * 获取指定层级的父级(包括自身)
 * @param {Record<string, any>[]} data 数据源
 * @param {(item) => boolean} cb 当前数据项是否匹配
 */
export declare function getChained<T extends Record<string, any>>(data: T[], cb: (item: T) => boolean, childrenKey?: string): T[];
/**
 * 获取渲染节点
 * @param {string | object | Function} node 需渲染元素
 */
export declare function getNode(node: string | ((...args: any[]) => VNode) | VNode | undefined | null, ...args: any[]): {};
/**
 * 通过字符串路径获取值
 * @example get(person, 'friends[0].name')
 */
export declare function get<TDefault = unknown>(value: any, path: string, defaultValue?: TDefault): TDefault;
/**
 * 判断对象是否存在指定属性
 * @example hasOwn({}, 'a')
 */
export declare function hasOwn<T extends Record<string, any>, K extends keyof T = keyof T>(obj: T, key: K): boolean;
